@@ -16,6 +16,7 @@
 
 import zipfile
 import six
+import sys
 import logging
 import uuid
 import warnings
@@ -36,7 +37,7 @@ from ebooklib.utils import parse_string, parse_html_string, guess_type, get_page
 
 
 # Version of EPUB library
-VERSION = (0, 18, 1)
+VERSION = (0, 19, 0)
 
 NAMESPACES = {'XML': 'http://www.w3.org/XML/1998/namespace',
               'EPUB': 'http://www.idpf.org/2007/ops',
@@ -496,8 +497,8 @@ class EpubNav(EpubHtml):
     Represents Navigation Document in the EPUB file.
     """
 
-    def __init__(self, uid='nav', file_name='nav.xhtml', media_type='application/xhtml+xml', title=''):
-        super(EpubNav, self).__init__(uid=uid, file_name=file_name, media_type=media_type, title=title)
+    def __init__(self, uid='nav', file_name='nav.xhtml', media_type='application/xhtml+xml', title='', direction=None):
+        super(EpubNav, self).__init__(uid=uid, file_name=file_name, media_type=media_type, title=title, direction=direction)
 
     def is_chapter(self):
         """
@@ -870,7 +871,9 @@ class EpubWriter(object):
         'play_order': {
             'enabled': False,
             'start_from': 1
-        }
+        },
+        'raise_exceptions': False,
+        'compresslevel': 6
     }
 
     def __init__(self, name, book, options=None):
@@ -956,7 +959,7 @@ class EpubWriter(object):
 
                             el.text = v[0]
                         except ValueError:
-                            logging.error('Could not create metadata "{}".'.format(name))
+                            logging.info('Could not create metadata "{}".'.format(name))
 
     def _write_opf_manifest(self, root):
         manifest = etree.SubElement(root, 'manifest')
@@ -1133,6 +1136,8 @@ class EpubWriter(object):
             })
 
         body = etree.SubElement(root, 'body')
+        if item.direction:
+            body.set('dir', item.direction)
         nav = etree.SubElement(body, 'nav', {
             '{%s}type' % NAMESPACES['EPUB']: 'toc',
             'id': 'id',
@@ -1148,11 +1153,11 @@ class EpubWriter(object):
                 if isinstance(item, tuple) or isinstance(item, list):
                     li = etree.SubElement(ol, 'li')
                     if isinstance(item[0], EpubHtml):
-                        a = etree.SubElement(li, 'a', {'href': os.path.relpath(item[0].file_name, nav_dir_name)})
+                        a = etree.SubElement(li, 'a', {'href': zip_path.relpath(item[0].file_name, nav_dir_name)})
                     elif isinstance(item[0], Section) and item[0].href != '':
-                        a = etree.SubElement(li, 'a', {'href': os.path.relpath(item[0].href, nav_dir_name)})
+                        a = etree.SubElement(li, 'a', {'href': zip_path.relpath(item[0].href, nav_dir_name)})
                     elif isinstance(item[0], Link):
-                        a = etree.SubElement(li, 'a', {'href': os.path.relpath(item[0].href, nav_dir_name)})
+                        a = etree.SubElement(li, 'a', {'href': zip_path.relpath(item[0].href, nav_dir_name)})
                     else:
                         a = etree.SubElement(li, 'span')
                     a.text = item[0].title
@@ -1161,11 +1166,11 @@ class EpubWriter(object):
 
                 elif isinstance(item, Link):
                     li = etree.SubElement(ol, 'li')
-                    a = etree.SubElement(li, 'a', {'href': os.path.relpath(item.href, nav_dir_name)})
+                    a = etree.SubElement(li, 'a', {'href': zip_path.relpath(item.href, nav_dir_name)})
                     a.text = item.title
                 elif isinstance(item, EpubHtml):
                     li = etree.SubElement(ol, 'li')
-                    a = etree.SubElement(li, 'a', {'href': os.path.relpath(item.file_name, nav_dir_name)})
+                    a = etree.SubElement(li, 'a', {'href': zip_path.relpath(item.file_name, nav_dir_name)})
                     a.text = item.title
 
         _create_section(nav, self.book.toc)
@@ -1203,7 +1208,7 @@ class EpubWriter(object):
                 guide_type = elem.get('type', '')
                 a_item = etree.SubElement(li_item, 'a', {
                     '{%s}type' % NAMESPACES['EPUB']: guide_to_landscape_map.get(guide_type, guide_type),
-                    'href': os.path.relpath(_href, nav_dir_name)
+                    'href': zip_path.relpath(_href, nav_dir_name)
                 })
                 a_item.text = _title
 
@@ -1238,7 +1243,7 @@ class EpubWriter(object):
                     _title = label
 
                     a_item = etree.SubElement(li_item, 'a', {
-                        'href': os.path.relpath(_href, nav_dir_name),
+                        'href': zip_path.relpath(_href, nav_dir_name),
                     })
                     a_item.text = _title
 
@@ -1361,7 +1366,7 @@ class EpubWriter(object):
 
     def write(self):
         # check for the option allowZip64
-        self.out = zipfile.ZipFile(self.file_name, 'w', zipfile.ZIP_DEFLATED)
+        self.out = zipfile.ZipFile(self.file_name, 'w', zipfile.ZIP_DEFLATED, compresslevel=self.options['compresslevel'])
         self.out.writestr('mimetype', 'application/epub+zip', compress_type=zipfile.ZIP_STORED)
 
         self._write_container()
@@ -1391,7 +1396,7 @@ class EpubReader(object):
         self._check_deprecated()
 
     def _check_deprecated(self):
-        if not self.options.get('ignore_ncx'):
+        if self.options.get('ignore_ncx') is None:
             warnings.warn('In the future version we will turn default option ignore_ncx to True.')
 
     def process(self):
@@ -1420,7 +1425,7 @@ class EpubReader(object):
         meta_inf = self.read_file('META-INF/container.xml')
         tree = parse_string(meta_inf)
 
-        for root_file in tree.findall('//xmlns:rootfile[@media-type]', namespaces={'xmlns': NAMESPACES['CONTAINERNS']}):
+        for root_file in tree.findall('.//xmlns:rootfile[@media-type]', namespaces={'xmlns': NAMESPACES['CONTAINERNS']}):
             if root_file.get('media-type') == 'application/oebps-package+xml':
                 self.opf_file = root_file.get('full-path')
                 self.opf_dir = zip_path.dirname(self.opf_file)
@@ -1606,7 +1611,7 @@ class EpubReader(object):
                 link_node = item_node.find('a')
 
                 if sublist_node is not None:
-                    title = item_node[0].text
+                    title = item_node[0].text_content()
                     children = parse_list(sublist_node)
 
                     if link_node is not None:
@@ -1615,7 +1620,7 @@ class EpubReader(object):
                     else:
                         items.append((Section(title), children))
                 elif link_node is not None:
-                    title = link_node.text
+                    title = link_node.text_content()
                     href = zip_path.normpath(zip_path.join(base_path, link_node.get('href')))
 
                     items.append(Link(href, title))
@@ -1745,7 +1750,14 @@ def write_epub(name, book, options=None):
     try:
         epub.write()
     except IOError:
-        pass
+        warnings.warn('In the future throwing exceptions while writing will be default behavior.')
+        t, v, tb = sys.exc_info()
+        if options and options.get('raise_exceptions'):
+            six.reraise(t, v, tb)
+        else:
+            return False
+
+    return True
 
 # READ
 
